Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4248)

Unified Diff: chrome/browser/printing/print_preview_message_handler.h

Issue 9030032: Get rid of a bunch of tab_contents.h includes from chrome. These are all trivial changes to use W... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: fix cros Created 8 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/printing/print_preview_message_handler.h
===================================================================
--- chrome/browser/printing/print_preview_message_handler.h (revision 116331)
+++ chrome/browser/printing/print_preview_message_handler.h (working copy)
@@ -24,7 +24,7 @@
// TabContents that owns it.
class PrintPreviewMessageHandler : public content::WebContentsObserver {
public:
- explicit PrintPreviewMessageHandler(TabContents* tab_contents);
+ explicit PrintPreviewMessageHandler(content::WebContents* web_contents);
virtual ~PrintPreviewMessageHandler();
// content::WebContentsObserver implementation.
@@ -33,10 +33,10 @@
content::NavigationController::ReloadType reload_type) OVERRIDE;
private:
// Gets the print preview tab associated with the TabContents being observed.
TabContentsWrapper* GetPrintPreviewTab();
// Helper function to return the TabContentsWrapper for tab_contents().
TabContentsWrapper* tab_contents_wrapper();
// Common code between failure handlers. Returns a PrintPreviewUI* if there
« no previous file with comments | « chrome/browser/printing/background_printing_manager.cc ('k') | chrome/browser/printing/print_preview_message_handler.cc » ('j') | no next file with comments »
@@ -33,10 +33,10 @@
content::NavigationController::ReloadType reload_type) OVERRIDE;
private:
- // Gets the print preview tab associated with the TabContents being observed.
+ // Gets the print preview tab associated with the WebContents being observed.
TabContentsWrapper* GetPrintPreviewTab();
@@ -33,10 +33,10 @@
TabContentsWrapper* GetPrintPreviewTab();
- // Helper function to return the TabContentsWrapper for tab_contents().
+ // Helper function to return the TabContentsWrapper for web_contents().
TabContentsWrapper* tab_contents_wrapper();
// Common code between failure handlers. Returns a PrintPreviewUI* if there

Powered by Google App Engine
This is Rietveld 408576698